@@ -121,7 +121,9 @@ API_REFERENCE = {
                     "TransformerMixin",
                     "clone",
                     "is_classifier",
+                    "is_clusterer",
                     "is_regressor",
+                    "is_outlier_detector",
                 ],
             }
         ],
@@ -239,6 +241,7 @@ API_REFERENCE = {
                     "fetch_20newsgroups_vectorized",
                     "fetch_california_housing",
                     "fetch_covtype",
+                    "fetch_file",
                     "fetch_kddcup99",
                     "fetch_lfw_pairs",
                     "fetch_lfw_people",
@@ -384,6 +387,7 @@ API_REFERENCE = {
                     "InconsistentVersionWarning",
                     "NotFittedError",
                     "UndefinedMetricWarning",
+                    "EstimatorCheckFailedWarning",
                 ],
             },
         ],
@@ -458,6 +462,16 @@ API_REFERENCE = {
             },
         ],
     },
+    "sklearn.frozen": {
+        "short_summary": "Frozen estimators.",
+        "description": None,
+        "sections": [
+            {
+                "title": None,
+                "autosummary": ["FrozenEstimator"],
+            },
+        ],
+    },
     "sklearn.gaussian_process": {
         "short_summary": "Gaussian processes.",
         "description": _get_guide("gaussian_process"),
@@ -535,7 +549,7 @@ API_REFERENCE = {
         ],
     },
     "sklearn.kernel_approximation": {
-        "short_summary": "Isotonic regression.",
+        "short_summary": "Kernel approximation.",
         "description": _get_guide("kernel_approximation"),
         "sections": [
             {
@@ -1158,6 +1172,13 @@ API_REFERENCE = {
                     "safe_mask",
                     "safe_sqr",
                     "shuffle",
+                    "Tags",
+                    "InputTags",
+                    "TargetTags",
+                    "ClassifierTags",
+                    "RegressorTags",
+                    "TransformerTags",
+                    "get_tags",
                 ],
             },
             {
@@ -1174,6 +1195,7 @@ API_REFERENCE = {
                     "validation.check_symmetric",
                     "validation.column_or_1d",
                     "validation.has_fit_parameter",
+                    "validation.validate_data",
                 ],
             },
             {
@@ -1276,6 +1298,7 @@ API_REFERENCE = {
                 "autosummary": [
                     "estimator_checks.check_estimator",
                     "estimator_checks.parametrize_with_checks",
+                    "estimator_checks.estimator_checks_generator",
                 ],
             },
             {
