@@ -10,7 +10,7 @@ from sklearn.datasets import get_data_home
 from sklearn.datasets._base import _pkl_filepath
 from sklearn.datasets._twenty_newsgroups import CACHE_NAME
 from sklearn.utils._testing import SkipTest, check_skip_network
-from sklearn.utils.fixes import _IS_PYPY, np_base_version, parse_version, sp_version
+from sklearn.utils.fixes import np_base_version, parse_version, sp_version
 
 
 def setup_labeled_faces():
@@ -34,8 +34,6 @@ def setup_twenty_newsgroups():
 
 
 def setup_working_with_text_data():
-    if _IS_PYPY and os.environ.get("CI", None):
-        raise SkipTest("Skipping too slow test with PyPy on CI")
     check_skip_network()
     cache_path = _pkl_filepath(get_data_home(), CACHE_NAME)
     if not exists(cache_path):
